==> v2.13.0.zip: mcuxpresso_lpc804/docs/MCUXpresso SDK API Reference Manual_LPC804/a00008.js <==
var a00008 =
[
    [ "acomp_config_t", "a00008.html#a00100", [
      [ "enableSyncToBusClk", "a00008.html#a6f9542645b06542277cb07ea138e5064", null ],
      [ "hysteresisSelection", "a00008.html#a46ecb6f7efe54967d816deafdf1c65ce", null ]
    ] ],
    [ "acomp_ladder_config_t", "a00008.html#a00101", [
      [ "ladderValue", "a00008.html#a8271667393096dad310f8b2e486b1c4b", null ],
      [ "referenceVoltage", "a00008.html#a66356c0246938695521e8a0ece69cf11", null ]
    ] ],
    [ "FSL_ACOMP_DRIVER_VERSION", "a00008.html#ga856c35b78deb42642464ecfdb8dfa8aa", null ],
    [ "acomp_ladder_reference_voltage_t", "a00008.html#ga7ad629d52b0a70f95cd2ddb3bee8ab5f", [
      [ "kACOMP_LadderRefVoltagePinVDD", "a00008.html#gga7ad629d52b0a70f95cd2ddb3bee8ab5fa70a5aa61894fc8d2195652c2fa3423aa", null ],
      [ "kACOMP_LadderRefVoltagePinVDDCMP", "a00008.html#gga7ad629d52b0a70f95cd2ddb3bee8ab5fa56718eb64fdbbd04648466547b326c35", null ]
    ] ],
    [ "acomp_interrupt_enable_t", "a00008.html#ga178d521ca2ee7f33d518b30dfb627d20", [
      [ "kACOMP_InterruptsFallingEdgeEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20ad015e6ad9b09be27a6de122fde6b3997", null ],
      [ "kACOMP_InterruptsRisingEdgeEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20a25801b009aba402b9810189eb8545b8b", null ],
      [ "kACOMP_InterruptsBothEdgesEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20a23743234a07f6c25a2b14cca0cd863c7", null ],
      [ "kACOMP_InterruptsDisable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20a629a3a054d3fde07b8f1d4974a9d070d", null ]
    ] ],
    [ "acomp_hysteresis_selection_t", "a00008.html#gaa7c0a15052b6421941faad3c6ea3a5ac", [
      [ "kACOMP_HysteresisNoneSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acae003c683374deba88f335221e4f6c62b", null ],
      [ "kACOMP_Hysteresis5MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acae6c2b1547a7e476425962d46b44a00f9", null ],
      [ "kACOMP_Hysteresis10MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5aca25ed95469736b1383c06835f1a59a6f7", null ],
      [ "kACOMP_Hysteresis20MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acab609612c0f5c6987b71f287d0ab8e02c", null ]
    ] ],
    [ "ACOMP_Init", "a00008.html#gae8afb04a61cd16f74eba67061409cd30", null ],
    [ "ACOMP_Deinit", "a00008.html#ga4e2589a3a011cb833649e301be7fff8c", null ],
    [ "ACOMP_GetDefaultConfig", "a00008.html#gae217e6b6f23e998b1bfa387e1f3f4181", null ],
    [ "ACOMP_EnableInterrupts", "a00008.html#ga33fc82023d54cc469fc62ed866a3ca19", null ],
    [ "ACOMP_GetInterruptsStatusFlags", "a00008.html#ga331e1a82fe5f3d36ee0b10ddea928cd0", null ],
    [ "ACOMP_ClearInterruptsStatusFlags", "a00008.html#ga013efc3edfbbd3f7f5044fc7bc2ce802", null ],
    [ "ACOMP_GetOutputStatusFlags", "a00008.html#ga0ea4f61940e0c270858758d51ae1a4d3", null ],
    [ "ACOMP_SetInputChannel", "a00008.html#gaff80c9cfc3eb8114fcdb525b507f7ba3", null ],
    [ "ACOMP_SetLadderConfig", "a00008.html#ga6b5b26d4b5e00361635aede71b048ffb", null ]
];

==> v2.14.0.zip: mcuxpresso_lpc804/docs/MCUXpresso SDK API Reference Manual_LPC804/a00008.js <==
var a00008 =
[
    [ "acomp_config_t", "a00008.html#a00101", [
      [ "enableSyncToBusClk", "a00008.html#a6f9542645b06542277cb07ea138e5064", null ],
      [ "hysteresisSelection", "a00008.html#a46ecb6f7efe54967d816deafdf1c65ce", null ]
    ] ],
    [ "acomp_ladder_config_t", "a00008.html#a00102", [
      [ "ladderValue", "a00008.html#a8271667393096dad310f8b2e486b1c4b", null ],
      [ "referenceVoltage", "a00008.html#a66356c0246938695521e8a0ece69cf11", null ]
    ] ],
    [ "FSL_ACOMP_DRIVER_VERSION", "a00008.html#ga856c35b78deb42642464ecfdb8dfa8aa", null ],
    [ "acomp_ladder_reference_voltage_t", "a00008.html#ga7ad629d52b0a70f95cd2ddb3bee8ab5f", [
      [ "kACOMP_LadderRefVoltagePinVDD", "a00008.html#gga7ad629d52b0a70f95cd2ddb3bee8ab5fa70a5aa61894fc8d2195652c2fa3423aa", null ],
      [ "kACOMP_LadderRefVoltagePinVDDCMP", "a00008.html#gga7ad629d52b0a70f95cd2ddb3bee8ab5fa56718eb64fdbbd04648466547b326c35", null ]
    ] ],
    [ "acomp_interrupt_enable_t", "a00008.html#ga178d521ca2ee7f33d518b30dfb627d20", [
      [ "kACOMP_InterruptsFallingEdgeEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20ad015e6ad9b09be27a6de122fde6b3997", null ],
      [ "kACOMP_InterruptsRisingEdgeEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20a25801b009aba402b9810189eb8545b8b", null ],
      [ "kACOMP_InterruptsBothEdgesEnable", "a00008.html#gga178d521ca2ee7f33d518b30dfb627d20a23743234a07f6c25a2b14cca0cd863c7", null ]
    ] ],
    [ "acomp_hysteresis_selection_t", "a00008.html#gaa7c0a15052b6421941faad3c6ea3a5ac", [
      [ "kACOMP_HysteresisNoneSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acae003c683374deba88f335221e4f6c62b", null ],
      [ "kACOMP_Hysteresis5MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acae6c2b1547a7e476425962d46b44a00f9", null ],
      [ "kACOMP_Hysteresis10MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5aca25ed95469736b1383c06835f1a59a6f7", null ],
      [ "kACOMP_Hysteresis20MVSelection", "a00008.html#ggaa7c0a15052b6421941faad3c6ea3a5acab609612c0f5c6987b71f287d0ab8e02c", null ]
    ] ],
    [ "ACOMP_Init", "a00008.html#gae8afb04a61cd16f74eba67061409cd30", null ],
    [ "ACOMP_Deinit", "a00008.html#ga4e2589a3a011cb833649e301be7fff8c", null ],
    [ "ACOMP_GetDefaultConfig", "a00008.html#gae217e6b6f23e998b1bfa387e1f3f4181", null ],
    [ "ACOMP_EnableInterrupts", "a00008.html#ga33fc82023d54cc469fc62ed866a3ca19", null ],
    [ "ACOMP_GetInterruptsStatusFlags", "a00008.html#ga331e1a82fe5f3d36ee0b10ddea928cd0", null ],
    [ "ACOMP_ClearInterruptsStatusFlags", "a00008.html#ga013efc3edfbbd3f7f5044fc7bc2ce802", null ],
    [ "ACOMP_GetOutputStatusFlags", "a00008.html#ga0ea4f61940e0c270858758d51ae1a4d3", null ],
    [ "ACOMP_SetInputChannel", "a00008.html#gaff80c9cfc3eb8114fcdb525b507f7ba3", null ],
    [ "ACOMP_SetLadderConfig", "a00008.html#ga6b5b26d4b5e00361635aede71b048ffb", null ]
];
